# k3ut

[![Build Status](https://travis-ci.com/pykit3/k3ut.svg?branch=master)](https://travis-ci.com/pykit3/k3ut)
[![Documentation Status](https://readthedocs.org/projects/k3ut/badge/?version=stable)](https://k3ut.readthedocs.io/en/stable/?badge=stable)
[![Package](https://img.shields.io/pypi/pyversions/k3ut)](https://pypi.org/project/k3ut)

unittest util

k3ut is a component of [pykit3] project: a python3 toolkit set.


# Install

```
pip install k3ut
```

# Synopsis

```python

```

#   Author

Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>

#   Copyright and License

The MIT License (MIT)

Copyright (c) 2015 Zhang Yanpo (张炎泼) <drdr.xp@gmail.com>


[pykit3]: https://github.com/pykit3